@@ -17,6 +17,7 @@
 #include "chxj_tag_util.h"
 #include "chxj_url_encode.h"
 #include "chxj_str_util.h"
+#include "chxj_jreserved_tag.h"
 
 
 /**
@@ -591,10 +592,20 @@ qs_get_parse_attr(Doc *doc, Node *tag, apr_pool_t *pool)
 
 
 char *
-chxj_form_action_to_hidden_tag(request_rec *r, apr_pool_t *pool, const char *str, int xmlFlag, int post, char **new_query_string, int docomo)
+chxj_form_action_to_hidden_tag(
+  request_rec         *r,
+  apr_pool_t          *pool,
+  const char          *str,
+  int                 xmlFlag,
+  int                 post,
+  char                **new_query_string,
+  int                 docomo,
+  int                 softbank,
+  chxjconvrule_entry  *entryp)
 {
   char *s = apr_pstrdup(pool, str);
   *new_query_string = NULL;
+  int no_qsconv_flag = (((unsigned int)entryp->action & CONVRULE_QSCONV_OFF_BIT) != 0);
   if (!s) return NULL;
   if (chxj_starts_with(s, "http://") || chxj_starts_with(s, "https://")) {
     apr_uri_t url;
@@ -621,21 +632,37 @@ chxj_form_action_to_hidden_tag(request_rec *r, apr_pool_t *pool, const char *str
       if (!val) val = "";
     }
     char *tmp = NULL;
-    if (post && strcasecmp(key, "guid") == 0 && docomo) {
-      *new_query_string = apr_psprintf(pool, "%s=%s", key, val);
+    
+    if (no_qsconv_flag) {
+      if (*new_query_string) {
+        *new_query_string = apr_psprintf(pool, "%s&%s=%s", *new_query_string, chxj_jreserved_to_safe_tag(r, key, entryp), val);
+      }
+      else {
+        *new_query_string = apr_psprintf(pool, "%s=%s", chxj_jreserved_to_safe_tag(r, key, entryp), val);
+      }
     }
     else {
-      if (! post || strcasecmp(key, "_chxj_cc") == 0 || strcasecmp(key, "_chxj_nc") == 0) {
-        tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"%s\" value=\"%s\"%s>", key, chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
+      if (post && strcasecmp(key, "guid") == 0 && docomo) {
+        *new_query_string = apr_psprintf(pool, "%s=%s", key, val);
       }
       else {
-        tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"_chxj_qs_%s\" value=\"%s\"%s>", key, chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
-      }
-      if (result) {
-        result = apr_pstrcat(pool, result, tmp, NULL);
-      }
-      else {
-        result = tmp;
+        if (! post || strcasecmp(key, "_chxj_cc") == 0 || strcasecmp(key, "_chxj_nc") == 0) {
+          if (softbank) {
+            tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"%s\" value=\"%s\"%s>", chxj_jreserved_to_safe_tag(r, key, entryp), chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
+          }
+          else {
+            tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"%s\" value=\"%s\"%s>", key, chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
+          }
+        }
+        else {
+          tmp = apr_psprintf(pool, "<input type=\"hidden\" name=\"_chxj_qs_%s\" value=\"%s\"%s>", key, chxj_url_decode(pool, val), (xmlFlag == 1) ? " /" : "");
+        }
+        if (result) {
+          result = apr_pstrcat(pool, result, tmp, NULL);
+        }
+        else {
+          result = tmp;
+        }
       }
     }
   }
